import 'dart:async';

import 'package:datami_plugin/datami_plugin.dart';
import 'package:datami_plugin/smi_status.dart';
import 'package:flutter/material.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _smiStatus = 'Not set';

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    DatamiPlugin.addSdStateChangeListener(_onSmiStatusChange);

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;
  }

  void _onSmiStatusChange(SmiStatus smiStatus) {
    setState(() {
      switch (smiStatus) {
        case SmiStatus.wifi:
          _smiStatus = 'Wifi';
          break;
        case SmiStatus.sd_not_available:
          _smiStatus = 'Not available';
          break;
        case SmiStatus.sd_available:
          _smiStatus = 'Available';
          break;
        case SmiStatus.unknown:
        default:
          _smiStatus = 'Unknown';
      }
    });
  }

  Future<void> initSmi() async {
    setState(() {
      _smiStatus = 'Initializing...';
    });

    await DatamiPlugin.initSponsoredData(
        smiKey: '',
        userID: 'io.skore.chatbot.viavarejo',
        onSmiStatusChange: _onSmiStatusChange);
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              Row(mainAxisSize: MainAxisSize.min, children: <Widget>[
                Text('Status: '),
                Text('$_smiStatus',
                    style: TextStyle(fontWeight: FontWeight.bold))
              ]),
//              Padding(
//                  padding: const EdgeInsets.only(top: 10),
//                  child: RaisedButton(
//                      child: Text('Test Datami'), onPressed: initSmi)
//              )
            ],
          ),
        ),
      ),
    );
  }
}
