import 'dart:async';
import 'dart:developer';

import 'package:datami_plugin/smi_status.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class DatamiPlugin {
  static const MethodChannel _channel = const MethodChannel('datami_plugin');

  static SmiStatus _getSmiStatus(int status) {
    switch (status) {
      case 1:
        return SmiStatus.wifi;
      case 2:
        return SmiStatus.sd_available;
      case 3:
        return SmiStatus.sd_not_available;
      default:
        return SmiStatus.unknown;
    }
  }

  static Future<bool> initSponsoredData({@required String smiKey, @required String userID, onSmiStatusChange}) async {
    try {
      await _channel.invokeMethod('initSponsoredData', <String, dynamic>{'smiKey': smiKey, 'userID': userID});
    } on PlatformException catch (e) {
      log(e.message);
      return false;
    }
    return true;
  }

  static Future<bool> addSdStateChangeListener(onSmiStatusChange) async {
    _initializeChannel(onSmiStatusChange: onSmiStatusChange);
    int result;
    try {
      result = await _channel.invokeMethod('addSdStateChangeListener');
    } on PlatformException catch (e) {
      log(e.message);
      return false;
    }
    return result == 0;
  }

  static void _initializeChannel({onSmiStatusChange}) {
    _channel.setMethodCallHandler((MethodCall call) async {
      String method = call.method;
      if (method == 'onSmiStatusChange' && call.arguments is int) {
        SmiStatus smiStatus = _getSmiStatus(call.arguments);
        onSmiStatusChange(smiStatus);
      }
    });
  }
}
